@@ -1,9 +1,9 @@
 
-#host = 'https://api.segment.io'
-host = 'http://localhost:7001'
+host = 'https://api.segment.io'
 
 endpoints = {
     'track': '/v1/track',
     'identify': '/v1/identify',
+    'alias': '/v1/alias',
     'batch': '/v1/import'
 }
